package com.util;

import java.io.File;
import java.util.List;
import net.jimmc.jshortcut.JShellLink;
import org.eclipse.swt.program.Program;
import com.model.DosboxVersion;
import com.model.Profile;
import com.model.Settings;


public abstract class PlatformUtils {

	public static final boolean IS_WINDOWS = (File.separatorChar == '\\');
	public static final boolean IS_LINUX = (File.separatorChar == '/');
	public static final String DB_EXECUTABLE = IS_WINDOWS? "DOSBox.exe": "dosbox";
	
	
	public static String toNativePath(String dosboxFileLocation) {
		if (IS_LINUX)
			return dosboxFileLocation.replace('\\', File.separatorChar);
		else
			return dosboxFileLocation;
  }
	
	public static String toDosboxPath(String hostFileLocation) {
		if (IS_LINUX)
			return hostFileLocation.replace('/', '\\');
		else
			return hostFileLocation;
  }
	
	public static String archiveToNativePath(String archiveEntry) {
		if (IS_LINUX)
			return archiveEntry.replace('\\', File.separatorChar);
		else
			return archiveEntry.replace('/', File.separatorChar);
	}
	
	public static void openForEditing(String file) {
		Program        p = Program.findProgram(".conf");
		if (p == null) p = Program.findProgram(".txt");
		if (p == null) p = Program.findProgram(".inf");
		if (p == null) p = Program.findProgram(".ini");
		if (p == null) p = Program.findProgram(".cfg");
		if (p == null) p = Program.findProgram(".java");
    if (p == null) p = Program.findProgram(".doc");
    if (p != null)
    	p.execute (file);
    else
    	System.err.println("Cannot open \"" + file + "\"");
	}
	
	public static void openForBrowsing(String url) {
		Program p = Program.findProgram(".html");
    if (p != null)
    	p.execute (url);
    else
    	System.err.println("Cannot open \"" + url + "\"");
	}
	
	public static void createShortcut(Profile profile, List<DosboxVersion> dbversionsList) {
		int dbversionIndex = ListUtils.findTIDosboxVersion(dbversionsList, profile.getDbversionId());
    DosboxVersion dbversion = dbversionsList.get(dbversionIndex);
    String params = "";
    if (dbversion.isMultiConfig())
    	params += "-conf " + FileUtils.DOSBOX_CONF + " "; 
    params += "-conf \"" + profile.getCanonicalConfPathAndFile() + "\"";
    if (Settings.getInstance().getBooleanValue("dosbox", "hideconsole")) {
  		params += " -noconsole";
  	}
    JShellLink link = new JShellLink();
    link.setFolder(JShellLink.getDirectory("desktop"));
    link.setName(profile.getTitle().replaceAll("[:?*]", " "));
    link.setPath(dbversion.getExecutable());
    link.setArguments(params);
    link.setDescription("Run " + profile.getTitle() + " in DOSBox");
    link.save();
	}
}
